==> ejc-middlemeasurement-impl-3.0.0-20221024.101540-187-sources.jar: com/ejianc/business/record/vo/RecordVisaclaimaccountVO.java <==
package com.ejianc.business.record.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 总包签证索赔台账变更记录表
 * 
 * @author generator
 * 
 */
public class RecordVisaclaimaccountVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String visaclaimaccountCode; // 变更记录编码
    private String billCode; // 单据编号
    private Long originalId; // 原始单据id（限额设计）
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long contract; // 合同
    private String contractName; // 
    private String remarks; // 备注
    private Long agentId; // 经办人
    private String agentName; // 经办人姓名
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date happenTime; // 发生时间
    private BigDecimal inSubmitAmountOur; // 我方报送金额
    private BigDecimal inConfirmAmountOpposite; //  对方确认金额
    private BigDecimal inAmountPayable; // 应付金额
    private BigDecimal inAmountRealPay; // 实付金额
    private BigDecimal exSubmitAmountOur; // 我方报送金额
    private BigDecimal exConfirmAmountOpposite; //  对方确认金额
    private BigDecimal exAmountPayable; // 应付金额
    private BigDecimal exAmountRealPay; // 实付金额
    private String changeReason; // 变更原因
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effectDate; // 生效时间
    
    private List<RecordVisaclaimaccountdetailVO> recordVisaclaimaccountdetailList = new ArrayList<>(); // 总包签证索赔台账变更记录子表

    public String getVisaclaimaccountCode() {
        return visaclaimaccountCode;
    }

    public void setVisaclaimaccountCode(String visaclaimaccountCode) {
        this.visaclaimaccountCode = visaclaimaccountCode;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")
    public Long getContract() {
        return contract;
    }

    @ReferDeserialTransfer
    public void setContract(Long contract) {
        this.contract = contract;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getAgentId() {
        return agentId;
    }

    @ReferDeserialTransfer
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public Date getHappenTime() {
        return happenTime;
    }

    public void setHappenTime(Date happenTime) {
        this.happenTime = happenTime;
    }
    public BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    public void setInSubmitAmountOur(BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    public BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    public void setInConfirmAmountOpposite(BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    public BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    public void setInAmountPayable(BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    public BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    public void setInAmountRealPay(BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    public BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    public void setExSubmitAmountOur(BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    public BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    public void setExConfirmAmountOpposite(BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    public BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    public void setExAmountPayable(BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    public BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    public void setExAmountRealPay(BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    
     public List<RecordVisaclaimaccountdetailVO> getRecordVisaclaimaccountdetailList() {
        return recordVisaclaimaccountdetailList;
     }

     public void setRecordVisaclaimaccountdetailList(List<RecordVisaclaimaccountdetailVO> recordVisaclaimaccountdetailList) {
        this.recordVisaclaimaccountdetailList = recordVisaclaimaccountdetailList;
     }
}

==> ejc-middlemeasurement-impl-3.0.0-20230130.073017-332-sources.jar: com/ejianc/business/record/vo/RecordVisaclaimaccountVO.java <==
package com.ejianc.business.record.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 总包签证索赔台账变更记录表
 * 
 * @author generator
 * 
 */
public class RecordVisaclaimaccountVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String visaclaimaccountCode; // 变更记录编码
    private String billCode; // 单据编号
    private Long originalId; // 原始单据id（限额设计）
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long projectId; // 项目id
    private String projectName; // 
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long contract; // 合同
    private String contractName; // 
    private String remarks; // 备注
    private Long agentId; // 经办人
    private String agentName; // 经办人姓名
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date happenTime; // 发生时间
    private BigDecimal inSubmitAmountOur; // 我方报送金额
    private BigDecimal inConfirmAmountOpposite; //  对方确认金额
    private BigDecimal inAmountPayable; // 应付金额
    private BigDecimal inAmountRealPay; // 实付金额
    private BigDecimal exSubmitAmountOur; // 我方报送金额
    private BigDecimal exConfirmAmountOpposite; //  对方确认金额
    private BigDecimal exAmountPayable; // 应付金额
    private BigDecimal exAmountRealPay; // 实付金额
    private String changeReason; // 变更原因
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effectDate; // 生效时间
    
//    private List<RecordVisaclaimaccountdetailVO> recordVisaclaimaccountdetailList = new ArrayList<>(); // 总包签证索赔台账变更记录子表
    private List<RecordVisaclaimaccountdetailVO> recordOutcontractList = new ArrayList<>(); // 总包签证索赔台账变更记录子表

    public String getVisaclaimaccountCode() {
        return visaclaimaccountCode;
    }

    public void setVisaclaimaccountCode(String visaclaimaccountCode) {
        this.visaclaimaccountCode = visaclaimaccountCode;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")
    public Long getContract() {
        return contract;
    }

    @ReferDeserialTransfer
    public void setContract(Long contract) {
        this.contract = contract;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getAgentId() {
        return agentId;
    }

    @ReferDeserialTransfer
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public Date getHappenTime() {
        return happenTime;
    }

    public void setHappenTime(Date happenTime) {
        this.happenTime = happenTime;
    }
    public BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    public void setInSubmitAmountOur(BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    public BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    public void setInConfirmAmountOpposite(BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    public BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    public void setInAmountPayable(BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    public BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    public void setInAmountRealPay(BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    public BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    public void setExSubmitAmountOur(BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    public BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    public void setExConfirmAmountOpposite(BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    public BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    public void setExAmountPayable(BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    public BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    public void setExAmountRealPay(BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    public List<RecordVisaclaimaccountdetailVO> getRecordOutcontractList() {
        return recordOutcontractList;
    }

    public void setRecordOutcontractList(List<RecordVisaclaimaccountdetailVO> recordOutcontractList) {
        this.recordOutcontractList = recordOutcontractList;
    }
}
